import IAAUtil from "./util";
import IAAEnv from "./env";
const IAA = IAAEnv.detectMiniProgramEnvironment() === 'tt' ? tt : wx
let reLogin = false;

let ajax = function (options) {
	let { data, conf } = options;
	return new Promise((resolve, reject) => {
		IAAUtil.ajax(options).then((res) => {
			if (res.data) {
				resolve(res.data);
			} else {
				resolve();
			}
		}, (res) => {
			// 返回状态码
			if (res.data && res.data.code === 300) {
				if (reLogin) return false;
				reLogin = true;
				resolve(
					IAAApi.IAALogin({ data, conf }).then((res) => {
						reLogin = false;
						return res
					})
				);
			} else {
				reject({
					msg: res.data ? res.data.msg || "网络异常，请重试" : res.errMsg,
				});
			}
		}
		);
	});
};

const IAAApi = {
	/**
	 * 初始化
	 * http://doc.1tsdk.com/138?page_id=3743
	 * @param {*} options 
	 * @returns 
	 */
	getDNSInfo(options) {
		return ajax({
			method: "GET",
			url: "/api/app/info",
			conf: { showLoading: false },
			...options,
		});
	},

	/**
	 * 登录
	 * http://doc.1tsdk.com/159?page_id=4378
	 * @param {*} options 
	 * @returns 
	 */
	login(options) {
		return ajax({
			method: "GET",
			url: "/api/user/login/mp",
			conf: { showLoading: false },
			...options,
		}).then((res) => {
			if (res) {
				IAA.setStorageSync("userInfo", res.data);
			}
			return res;
		}).catch((err) => {
			console.error(err);
			IAA.hideLoading();
		});
	},

	/**
	 * 调用小程序登录
	 * @param {*} options 
	 * @returns 
	 */
	IAALogin(options) {
		// 微信环境  抖音环境需要传入
		if (!IAAEnv.isDouyinMiniProgram()) {
			// 获取分享卡片进来是否带了分享人ID
			let { query } = IAA.getEnterOptionsSync();
			if (query && query.shareUserId) {
				options.data = {
					...options.data,
					shareUserId: query.shareUserId,
				};
			}
		}
		return new Promise((resolve, reject) => {
			IAA.login({
				force: true,
				success: (res) => {
					console.log('login---->', res)
					if (res.code) {
						options.data = {
							...options.data,
							code: res.code,
							anonymousCode: res.anonymousCode
						};
						resolve(this.login(options));
					} else {
						reject(res);
					}
				},
				fail: (res) => {
					console.log('login:fail---->', res)
					reject(res);
				},
			});
		});
	},

	/**
	 * 查询token是否失效
	 * @returns 
	 */
	tokenCheck() {
		return ajax({
			url: "/api/user/token/expire/check",
			conf: { showLoading: false },
		});
	},

	/**
	 * 活跃上报
	 * @param {*} options 
	 * @returns 
	 */
	activeRoleInfo(options = {}) {
		return ajax({
			method: "POST",
			url: "/api/user/active/call",
			conf: { showLoading: false },
			...options
		})
	},

	/**
	 * 埋点事件上报
	 * @param {*} options 
	 * @returns 
	 */
	trackRoleInfo(options = {}) {
		return ajax({
			method: "POST",
			url: "/api/event/log/track/call",
			conf: { showLoading: false },
			...options
		})
	},

	/**
	 * 完成观看广告事件
	 * @param {*} options 
	 * @returns 
	 */
	finishWatchAd(options = {}) {
		return ajax({
			method: "POST",
			url: "/api/event/finish/watch/ad/call",
			conf: { showLoading: false },
			...options
		})
	},

	
	/**
	 * 获取分享内容
	 * http://doc.1tsdk.com/159?page_id=4467
	 * @param {*} options 
	 * @returns 
	 */
	getShareInfo(options = {}) {
		return ajax({
			url: "/api/user/share",
			conf: { showLoading: false },
			...options,
		});
	},

	/**
	 * 退出注销
	 * @param {*} options 
	 * @returns 
	 */
	logout(options = {}) {
		return ajax({
			url: "/api/user/logout",
			conf: { showLoading: true },
			method: 'PATCH',
			...options
		});
	}
};

module.exports = IAAApi;
