let window = window || GameGlobal;
import IAAApi from "./api";
import IAAEnv from "./env";
const IAA = IAAEnv.detectMiniProgramEnvironment() === 'tt' ? tt : wx

window.qcIAASdk = {
	/**
	 * 初始化配置
	 * @param {*} options 
	 * @returns 
	 */
	init(options = {}) {
		if (options.channel) {
			window.channel = options.channel;
		}
		return new Promise((resolve, reject) => {
			IAAApi.getDNSInfo({ data: options.data || {} }).then((res) => {
				resolve(res);
			}, (err) => {
				reject(err);
			});
		});
	},


	timer: null,
	/**
	 * 开启定时器 活跃上报
	 */
	startTimer() {
		if (!this.timer) {
			IAAApi.activeRoleInfo();
			this.timer = setInterval(() => {
				IAAApi.activeRoleInfo();
			}, 1000 * 60 * 1);
		}
	},

	/**
	 * 登录前判断
	 * @param {*} options 
	 * @returns 
	 */
	login(options = {}) {
		let that = this;
		return new Promise((resolve, reject) => {
			let userInfo = IAA.getStorageSync("userInfo");
			if (userInfo.token) {
				console.log("token已存在");
				// 验证token
				IAA.checkSession({
					success() {
						console.log("检测session_key未过期");
						IAAApi.tokenCheck().then((res) => {
							if (res.data && res.data.result) {
								that.startTimer()
								resolve({ code: 200, data: userInfo, msg: "success", success: true });
							} else {
								console.log("token已过期");
								that.tologin(options).then((res) => resolve(res)).catch((err) => reject(err));
							}
						});
					},
					fail() {
						console.log("检测session_key已过期");
						that.tologin(options).then((res) => resolve(res)).catch((err) => reject(err));
					},
				});
			} else {
				that.tologin(options).then((res) => resolve(res)).catch((err) => reject(err));
			}
		});
	},

	/**
	 * 登录
	 * @param {*} options 
	 * @returns 
	 */
	tologin(options = {}) {
		console.log("重新登录=====>");
		return new Promise((resolve, reject) => {
			IAAApi.IAALogin(options).then((res) => {
				if (res.code === 200)
					this.startTimer()
				resolve(res);
			}, (err) => {
				reject({ msg: err.msg || "fail" });
			});
		});
	},

	/**
	 * 获取分享信息
	 * @returns 
	 */
	getShareInfo() {
		IAA.showShareMenu(); //设置开启当前页面分享按钮
		return IAAApi.getShareInfo().then((res) => {
			// 设置分享信息
			let { path, img, title, query } = res.data;
			console.log("设置分享信息======================>", path);
			if (IAAEnv.detectMiniProgramEnvironment() === 'wx') {
				wx.onShareAppMessage(() => {
					return {
						title,
						path,
						imageUrl: img,
					};
				});
			} else {
				tt.onShareAppMessage(() => {
					return {
						title,
						query: path,
						imageUrl: img,
					};
				});
			}

			return res;
		});
	},

	/**
	 * 埋点上报
	 * @param {*} options 
	 */
	trackRoleInfo(options = {}) {
		return new Promise((resolve, reject) => {
			IAAApi.trackRoleInfo(options).then((res) => {
				if (res.data) {
					resolve(res);
				} else {
					reject(res)
				}
			}, (err) => {
				reject({ msg: err.msg || "fail" });
			});
		})
	},

	/**
	 * 完成奖励上报
	 * @param {*} options 
	 */
	finishWatchAd(options = {}) {
		return new Promise((resolve, reject) => {
			setTimeout(() => {
				IAAApi.finishWatchAd(options).then((res) => {
					if (res.data) {
						resolve(res);
					} else {
						reject(res)
					}
				}, (err) => {
					reject({ msg: err.msg || "fail" });
				});
			}, 2000)
		})
	},

	/**
	 * 登出
	 * @param {*} options 
	 * @returns 
	 */
	logout(options = {}) {
		return new Promise((resolve, reject) => {
			IAAApi.logout(options).then((res) => {
				if (res.data) {
					IAA.removeStorageSync("userInfo");
					resolve(res);
				} else {
					reject(res)
				}
			}, (err) => {
				reject({ msg: err.msg || "fail" });
			});
		});
	}
};

module.exports = window.qcSdk;
