import IAAConfig from "./config";
import md5 from "./md5";
import IAAEnv from "./env";
const window = window || GameGlobal;
const IAA = IAAEnv.detectMiniProgramEnvironment() === 'tt' ? tt : wx

let IAAUtil = {
	
	/**
	 * 公共请求方法
	 * @param {*} options 
	 * @returns 
	 */
	ajax(options) {
		console.log('ajax=options====>', options)
		let conf = this.setting(options.conf);
		options.conf && delete options.conf;
		// 打开 loading，如果需要
		conf.showLoading && IAA.showLoading(conf.loadingParams);
		options.ts = Date.now()
		options = this.params(options);
		// 开启debug打印
		IAAConfig.debug && console.log(new Date().getTime(), options.url, options.data);
		//删除时间
		options.ts && delete options.ts
		return new Promise((resolve, reject) => {
			IAA.request({
				...options,
				success: (res) => {
					IAAConfig.debug && console.log(new Date().getTime(), options.url, res);
					// 关闭 loading，如果存在
					conf.showLoading && IAA.hideLoading();
					if (res.statusCode === 200 && res.data && (res.data.code === undefined || res.data.code === 200)) {
						resolve(res);
					} else {
						if (conf.showToast) {
							if (res.data && res.data.msg) {
								conf.toastParams.title = res.data.msg;
							}
							IAA.showToast(conf.toastParams);
						}
						reject(res);
					}
				},
				fail: (res) => {
					IAAConfig.debug && console.log(new Date().getTime(), options.url, res);
					// 关闭 loading，如果存在
					conf.showLoading && IAA.hideLoading();

					if (conf.showToast) {
						if (res.errMsg) {
							conf.toastParams.title = res.errMsg;
						}
						IAA.showToast(conf.toastParams);
					}

					reject(res);
				},
			});
		});
	},
	
	/**
	 * 参数
	 * @param {*} options 
	 * @returns 
	 */
	params(options) {
		// method
		options.method = (options.method || "GET").toUpperCase();
		let userInfo = IAA.getStorageSync('userInfo')
		console.log(' userInfo.token===>', userInfo.token)

		let configUrl = `signature=${this.sign(options)}&appKey=${IAAConfig.baseParams.appKey || window.appKey}&timestamp=${options.ts}&deviceSystem=${IAAConfig.deviceParams["device-os"]}&appServer=0`
		//header公共参数
		let header = {
			token: userInfo ? userInfo.token : '',
			channel: JSON.stringify(window.channel || IAAConfig.channelId || {})
		}
		// header 当post时加的数据格式
		if (options.method === "POST") {
			options.header = {
				"Content-Type": "application/json",
			};
		}
		// data 私有方法需要传数据的
		if (!options.private) {
			options.header = { ...options.header, ...header }
		}
		// url地址
		if (!/^http/.test(options.url)) {
			let url = IAAConfig.baseUrl + options.url;
			if (url.includes('?')) {
				options.url = url + '&' + configUrl
			} else {
				options.url = url + '?' + configUrl
			}
			
		}
		delete options.private;
		delete options.signUrl;

		return options;
	},

	/**
	 * 配置
	 * @param {*} conf 
	 * @returns 
	 */
	setting(conf = {}) {
		return {
			...IAAConfig.setting,
			...conf,
		};
	},

	/**
	 * 签名
	 * @param {*} options 
	 * @returns 
	 */
	sign(options) {
		let str = `appSecret=${IAAConfig.baseParams.appSecret || window.appSecret}&appKey=${IAAConfig.baseParams.appKey || window.appKey}&appServer=0&timestamp=${options.ts}`
		let sign = md5(str).toLocaleUpperCase()
		return sign;
	}
};

module.exports = IAAUtil;
